@@ -7,7 +7,7 @@ use warnings;
 use Exporter::Tiny ();
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.043_02';
+our $VERSION   = '0.034';
 
 sub import {
 	my $me     = shift;
@@ -68,21 +68,6 @@ also supported:
 
 This is a very small wrapper to simplify using L<Exporter::Tiny>.
 
-It does the following:
-
-=over
-
-=item * Marks your package as loaded in C<< %INC >>;
-
-=item * Pushes any function names in the import list onto your C<< @EXPORT_OK >>; and
-
-=item * Pushes C<< "Exporter::Tiny" >> onto your C<< @ISA >>.
-
-=back
-
-It doesn't set up C<< %EXPORT_TAGS >> or C<< @EXPORT >>, but there's
-nothing stopping you doing that yourself.
-
 =head1 BUGS
 
 Please report any bugs to
@@ -90,12 +75,7 @@ L<http://rt.cpan.org/Dist/Display.html?Queue=Exporter-Tiny>.
 
 =head1 SEE ALSO
 
-This module is just a wrapper around L<Exporter::Tiny>, so take a look
-at L<Exporter::Tiny::Manual::QuickStart> and
-L<Exporter::Tiny::Manual::Exporting> for further information on what
-features are available.
-
-Other interesting exporters: L<Sub::Exporter>, L<Exporter>.
+L<Exporter::Tiny>.
 
 =head1 AUTHOR
 
