@@ -5,7 +5,7 @@ use strict;
 use warnings; no warnings qw(void once uninitialized numeric redefine);
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.032';
+our $VERSION   = '0.034';
 our @EXPORT_OK = qw< mkopt mkopt_hash _croak >;
 
 sub _croak ($;@) { require Carp; my $fmt = shift; @_ = sprintf($fmt, @_); goto \&Carp::croak }
@@ -469,14 +469,14 @@ which I'd built into Type::Library:
    use Types::Standard "Str" => { -as => "String" };
 
 And so I decided to factor out code that could be shared by all Type-Tiny's
-exporters into a single place: L<Exporter::TypeTiny>.
+exporters into a single place: Exporter::TypeTiny.
 
-As of version 0.026, L<Exporter::TypeTiny> was also made available as
+As of version 0.026, Exporter::TypeTiny was also made available as
 L<Exporter::Tiny>, distributed independently on CPAN. CHOCOLATEBOY had
 convinced me that it was mature enough to live a life of its own.
 
 As of version 0.030, Type-Tiny depends on Exporter::Tiny and
-L<Exporter::TypeTiny> is being phased out.
+Exporter::TypeTiny is being phased out.
 
 =head1 OBLIGATORY EXPORTER COMPARISON
 
@@ -533,9 +533,14 @@ Sub::Exporter is installed.)
 Please report any bugs to
 L<http://rt.cpan.org/Dist/Display.html?Queue=Exporter-Tiny>.
 
+=head1 SUPPORT
+
+B<< IRC: >> support is available through in the I<< #moops >> channel
+on L<irc.perl.org|http://www.irc.perl.org/channels.html>.
+
 =head1 SEE ALSO
 
-L<Exporter::TypeTiny>,
+L<Exporter::Shiny>,
 L<Sub::Exporter>,
 L<Exporter>.
 
@@ -545,7 +550,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013 by Toby Inkster.
+This software is copyright (c) 2013-2014 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
